[svn-commits] trunk - r8100 in /trunk: app.c apps/app_queue.c asterisk.8 asterisk.c channel.c

svn-commits at lists.digium.com svn-commits at lists.digium.com
Mon Jan 16 10:37:46 MST 2006


Author: bweschke
Date: Mon Jan 16 11:37:44 2006
New Revision: 8100

URL: http://svn.digium.com/view/asterisk?rev=8100&view=rev
Log:
 Spelling corrections (mostly in comments and doxygen areas) #6249 


Modified:
    trunk/app.c
    trunk/apps/app_queue.c
    trunk/asterisk.8
    trunk/asterisk.c
    trunk/channel.c

Modified: trunk/app.c
URL: http://svn.digium.com/view/asterisk/trunk/app.c?rev=8100&r1=8099&r2=8100&view=diff
==============================================================================
--- trunk/app.c (original)
+++ trunk/app.c Mon Jan 16 11:37:44 2006
@@ -55,7 +55,7 @@
 
 /* !
 This function presents a dialtone and reads an extension into 'collect' 
-which must be a pointer to a **pre-initilized** array of char having a 
+which must be a pointer to a **pre-initialized** array of char having a 
 size of 'size' suitable for writing to.  It will collect no more than the smaller 
 of 'maxlen' or 'size' minus the original strlen() of collect digits.
 \return 0 if extension does not exist, 1 if extension exists

Modified: trunk/apps/app_queue.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_queue.c?rev=8100&r1=8099&r2=8100&view=diff
==============================================================================
--- trunk/asterisk.8 (original)
+++ trunk/asterisk.8 Mon Jan 16 11:37:44 2006
@@ -77,7 +77,7 @@
 Provide brief summary of command line arguments and terminate.
 .TP
 \fB-i\fR
-Prompt user to intialize any encrypted private keys for IAX2
+Prompt user to initialize any encrypted private keys for IAX2
 secure authentication during startup.
 .TP
 \fB-L \fIloadaverage\fB\fR

Modified: trunk/asterisk.c
URL: http://svn.digium.com/view/asterisk/trunk/asterisk.c?rev=8100&r1=8099&r2=8100&view=diff
==============================================================================
--- trunk/asterisk.c (original)
+++ trunk/asterisk.c Mon Jan 16 11:37:44 2006
@@ -1940,7 +1940,7 @@
 		/* Run as console (-c at startup, implies nofork) */
 		} else if (!strcasecmp(v->name, "console")) {
 			ast_set2_flag(&ast_options, ast_true(v->value), AST_OPT_FLAG_CONSOLE);
-		/* Run with highg priority if the O/S permits (-p at startup) */
+		/* Run with high priority if the O/S permits (-p at startup) */
 		} else if (!strcasecmp(v->name, "highpriority")) {
 			ast_set2_flag(&ast_options, ast_true(v->value), AST_OPT_FLAG_HIGH_PRIORITY);
 		/* Initialize RSA auth keys (IAX2) (-i at startup) */

Modified: trunk/channel.c
URL: http://svn.digium.com/view/asterisk/trunk/channel.c?rev=8100&r1=8099&r2=8100&view=diff
==============================================================================
--- trunk/channel.c (original)
+++ trunk/channel.c Mon Jan 16 11:37:44 2006
@@ -484,7 +484,7 @@
 	};
 	
 	
-	/* Find the first prefered codec in the format given */
+	/* Find the first preferred codec in the format given */
 	for (x=0; x < (sizeof(prefs) / sizeof(prefs[0]) ); x++)
 		if (fmts & prefs[x])
 			return prefs[x];
@@ -896,7 +896,7 @@
 	if(chan->music_state)
 		ast_moh_cleanup(chan);
 
-	/* Free translatosr */
+	/* Free translators */
 	if (chan->readtrans)
 		ast_translator_free_path(chan->readtrans);
 	if (chan->writetrans)
@@ -2907,7 +2907,7 @@
 	manager_event(EVENT_FLAG_CALL, "Rename", "Oldname: %s\r\nNewname: %s\r\nUniqueid: %s\r\n", newn, masqn, clone->uniqueid);
 	manager_event(EVENT_FLAG_CALL, "Rename", "Oldname: %s\r\nNewname: %s\r\nUniqueid: %s\r\n", orig, newn, original->uniqueid);
 
-	/* Swap the technlogies */	
+	/* Swap the technologies */	
 	t = original->tech;
 	original->tech = clone->tech;
 	clone->tech = t;



More information about the svn-commits mailing list
--- trunk/apps/app_queue.c (original)
+++ trunk/apps/app_queue.c Mon Jan 16 11:37:44 2006
@@ -223,7 +223,7 @@
 
 /*! \brief Persistent Members astdb family */
 static const char *pm_family = "/Queue/PersistentMembers";
-/* The maximum lengh of each persistent member queue database entry */
+/* The maximum length of each persistent member queue database entry */
 #define PM_MAX_LEN 2048
 
 /*! \brief queues.conf [general] option */
@@ -282,7 +282,7 @@
 	int pos;			/*!< Where we are in the queue */
 	int prio;			/*!< Our priority */
 	int last_pos_said;              /*!< Last position we told the user */
-	time_t last_periodic_announce_time;	/*!< The last time we played a periodic anouncement */
+	time_t last_periodic_announce_time;	/*!< The last time we played a periodic announcement */
 	time_t last_pos;                /*!< Last time we told the user their position */
 	int opos;			/*!< Where we started in the queue */
 	int handled;			/*!< Whether our call was handled */
@@ -2135,7 +2135,7 @@
 		peer = NULL;
 	if (!peer) {
 		if (to) {
-			/* Musta gotten hung up */
+			/* Must gotten hung up */
 			record_abandoned(qe);
 			res = -1;
 		} else {
@@ -2302,7 +2302,7 @@
 			ast_hangup(peer);
 		update_queue(qe->parent, member);
 		if (bridge == 0) 
-			res = 1; /* JDG: bridge successfull, leave app_queue */
+			res = 1; /* JDG: bridge successfully, leave app_queue */
 		else 
 			res = bridge; /* bridge error, stay in the queue */
 	}	
@@ -2332,7 +2332,7 @@
 }
 
 
-/* Dump all members in a specific queue to the databse
+/* Dump all members in a specific queue to the database
  *
  * <pm_family>/<queuename> = <interface>;<penalty>;<paused>[|...]
  *
@@ -2561,7 +2561,7 @@
 			paused_tok = strsep(&member, ";");
 
 			if (!penalty_tok) {
-				ast_log(LOG_WARNING, "Error parsing persisent member string for '%s' (penalty)\n", queue_name);
+				ast_log(LOG_WARNING, "Error parsing persistent member string for '%s' (penalty)\n", queue_name);
 				break;
 			}
 			penalty = strtol(penalty_tok, NULL, 10);
@@ -2592,7 +2592,7 @@
 
 	ast_mutex_unlock(&qlock);
 	if (db_tree) {
-		ast_log(LOG_NOTICE, "Queue members sucessfully reloaded from database.\n");
+		ast_log(LOG_NOTICE, "Queue members successfully reloaded from database.\n");
 		ast_db_freetree(db_tree);
 	}
 }

Modified: trunk/asterisk.8
URL: http://svn.digium.com/view/asterisk/trunk/asterisk.8?rev=8100&r1=8099&r2=8100&view=diff
==============================================================================